@@ -506,7 +506,7 @@ def invoke_web_service_task(conf, web_service_configs):
         payload = request_object.get("payload")
 
         if payload:
-            response, status = invoke_http_request(url, request_type, headers, payload)
+            response, status = invoke_http_request(url, request_type, headers, json_data=payload)
         else:
             response, status = invoke_http_request(url, request_type, headers)
         if is_success_request(status):
